use pyo3::prelude::*;
use pyo3::exceptions::PyRuntimeError;
use argon2::{Argon2, PasswordHasher, PasswordVerifier};
use argon2::password_hash::{SaltString, PasswordHash, rand_core::OsRng};

#[pyfunction]
pub fn hash_password(password: &str) -> PyResult<String> {
    let salt = SaltString::generate(&mut OsRng);
    let argon2 = Argon2::default();
    let password_hash = argon2.hash_password(password.as_bytes(), &salt)
        .map_err(|e| PyRuntimeError::new_err(e.to_string()))?
        .to_string();
    Ok(password_hash)
}

#[pyfunction]
pub fn verify_password(hash: &str, password: &str) -> PyResult<bool> {
    let argon2 = Argon2::default();
    let parsed_hash = PasswordHash::new(hash)
        .map_err(|e| PyRuntimeError::new_err(e.to_string()))?;
    argon2.verify_password(password.as_bytes(), &parsed_hash)
        .map_err(|e| PyRuntimeError::new_err(e.to_string()))
        .map(|_| true)
}

